@@ -5,9 +5,12 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <errno.h>
+#include <stdbool.h>
 
-void setgid_wrapper (int *ret, int *gid) {
-  Rprintf("Setting gid...\n");  
+void setgid_wrapper (int *ret, int *gid, bool *verbose) {
+  if(*verbose){
+	  Rprintf("Setting gid...\n");
+  }
   *ret = setgid (*gid);
   if(*ret != 0){
     *ret = errno;
